# Fairo Metrics 

A collection of metrics that are pre-certified and tested for use in the Fairo AI Governance Platform. 
This package can be used standalone or with the Fairo platform.
The metrics in this package are designed to test AI for fairness and quality. 
They have been curated for use in our system and are regularly updated. 

Please read our [documentation](https://fairo.readme.io/docs/) to get started.

For more information about Fairo, or to start a free trial, please visit our [website](http://www.fairo.ai).
